# [numbro](https://numbrojs.com/)

[![Join the chat at https://gitter.im/foretagsplatsen/numbro](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/foretagsplatsen/numbro?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

A javascript library for formatting and manipulating numbers.

[Website and documentation](http://foretagsplatsen.github.io/numbro)


# Travis Build Status

Master [![Build Status](https://travis-ci.org/foretagsplatsen/numbro.svg?branch=master)](https://travis-ci.org/foretagsplatsen/numbro)

Develop [![Build Status](https://travis-ci.org/foretagsplatsen/numbro.svg?branch=develop)](https://travis-ci.org/foretagsplatsen/numbro)

# NPM

[![NPM](https://nodei.co/npm/numbro.png?downloads=true)](https://nodei.co/npm/numbro/)

# Contributing

Please submit all pull requests to the `develop` branch.

1. Fork the library

2. [Install grunt](http://gruntjs.com/getting-started#installing-the-cli)

3. Run `npm install` to install dependencies

4. Add your tests to the files in `/tests`

5. To test your tests, run `grunt test`

6. When all your tests are passing, submit a pull request to the `develop` branch.


### Languages

Languages names follows the Microsoft culture name convention as found
[here](https://msdn.microsoft.com/en-us/library/ee825488.aspx). If Microsoft does not have a code
for the country/locale combination, use the format `lang-locale` where the language code is a 2
letter abbreviation from the list of [ISO 639-1 language
codes](http://en.wikipedia.org/wiki/List_of_ISO_639-1_codes) and the `localecode` is from the list
of [ISO 3166-1 country codes](http://en.wikipedia.org/wiki/ISO_3166-1)

### Language translations will not be merged without unit tests.

See [the english unit tests](https://github.com/foretagsplatsen/numbro/blob/master/tests/languages/en-GB.js) for an example.


# Changelog

See [CHANGELOG.md](CHANGELOG.md).


# Acknowledgements

`numbro` is forked from [Adam Draper](https://github.com/adamwdraper)'s project
[Numeral.js](http://numeraljs.com/), which was in turn inspired by and heavily borrowed from
[Moment.js](http://momentjs.com).


# License

Copyright © 2014 Adam Draper

Copyright © 2015 Företagsplatsen AB

---

Distributed under the MIT license. If you want to know more, see the `LICENSE` file.

The original license file for `Numeral.js` can be found in `LICENSE-Numeraljs`
